# coding=utf-8
from rest_framework import serializers
from apps.tenant.models import Tenant
from apps.tenant.employee.models import Employee
from utils.exceptions import CustomError
from apps.account.models import User

class TenantSerializer(serializers.ModelSerializer) :
    create_time = serializers.DateTimeField(format='%Y-%m-%d %H:%M', read_only=True)
    status_text = serializers.CharField(source='get_status_display', read_only=True)

    class Meta:
        model = Tenant
        fields = '__all__'

    def create(self, validated_data):
        if Tenant.is_exist(validated_data['company_name']):
            raise CustomError(u'名称为[%s]的租户已存在' % validated_data['company_name'])
        instance = super(TenantSerializer, self).create(validated_data)
        return instance

    def update(self, instance, validated_data):
        if instance.delete:
            raise CustomError(u'租户[%s]已经被删除，禁止修改' % instance.company_name)
        if Tenant.is_exist(validated_data['company_name'], instance.id):
            raise CustomError(u'名称为[%s]的租户已存在' % validated_data['company_name'])

        instance = super(TenantSerializer, self).update(instance, validated_data)
        return instance



